2020.12.12
==========
----

* Update Rupee symbol.
* Added minor modification for Python 3 compatibility.
* Add AFN cureency.


2014.7.13
=========
----

* Introduce ``config`` module.
* Move constant variables from ``initializer`` to ``config`` module.
* Raise exception if currency does not exist.
* Add Usage examples to ``README.rst``.
* Add Tests section to ``README.rst``


2014.7.12
=========
----

* Support many currencies.
* Full test suit.
* %100 test coverage.
* Initial release.
